<?php
/************************************************************************
 * MXChange v0.2.1                                    Start: 08/03/2004 *
 * ================                             Last change: 08/07/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-list_task.php                               *
 * -------------------------------------------------------------------- *
 * Short description : List all tasks                                   *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Alle Aufgaben auflisten                          *
 * -------------------------------------------------------------------- *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2008 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!IS_ADMIN())) {
	$INC = substr(dirname(__FILE__), 0, strpos(dirname(__FILE__), "/inc") + 4) . "/security.php";
	require($INC);
} elseif (!EXT_IS_ACTIVE("task")) {
	addFatalMessage(getMessage('EXTENSION_PROBLEM_EXT_INACTIVE'), "task");
	return;
}

// Add description as navigation point
ADD_DESCR("admin", __FILE__);

$whereStatement = "";
if (empty($_GET['type'])) $_GET['type'] = "your";

switch ($_GET['type'])
{
case "your": // List only your own open (new) tasks
	$whereStatement = "assigned_admin='".GET_CURRENT_ADMIN_ID()."' AND `status`='NEW' AND task_type != 'EXTENSION_UPDATE'";
	break;

case "updates": // List only updates assigned to you
	$whereStatement = "assigned_admin=".GET_CURRENT_ADMIN_ID()." AND `status`='NEW' AND task_type = 'EXTENSION_UPDATE'";
	break;

case "solved": // List only solved tasks assigned to you
	$whereStatement = "assigned_admin=".GET_CURRENT_ADMIN_ID()." AND `status`='SOLVED'";
	break;

case "unassigned": // List unassigned (but not deleted) tasks
	$whereStatement = "assigned_admin='0' AND status != 'DELETED'";
	break;

case "deleted": // List all deleted
	$whereStatement = "`status`='DELETED'";
	break;

case "closed": // List all closed
	$whereStatement = "assigned_admin=".GET_CURRENT_ADMIN_ID()." AND `status`='CLOSED'";
	break;

default: // Unknown type
	DEBUG_LOG(__FILE__, __LINE__, sprintf("Unknown task type %s detected.", $_GET['type']));
	LOAD_TEMPLATE("admin_settings_saved", false, sprintf(getMessage('ADMIN_TASK_UNKNOWN_MODE'), $_GET['type']));
	break;
}

if (!empty($whereStatement))
{
	$SEL = 0;
	if (isset($_POST['task'])) $SEL = SELECTION_COUNT($_POST['task']);
	if ((isset($_POST['assign'])) && ($SEL > 0)) {
		// Assign / do tasks
		LOAD_INC_ONCE("inc/modules/admin/overview-inc.php");
		if (empty($dmy)) $dmy = "";
		OUTPUT_SELECTED_TASKS($_POST, $dmy);
	} else {
		// Start listing tasks matching selected filter
		$result_tasks = SQL_QUERY("SELECT id, assigned_admin, userid, task_type, subject, text, task_created
FROM `{!_MYSQL_PREFIX!}_task_system`
WHERE ".$whereStatement."
ORDER BY userid DESC, task_type DESC, subject, task_created DESC", __FILE__, __LINE__);
		if (($SEL > 0) && (!IS_DEMO())) {
			// Only unassign / delete tasks when there are selected tasks posted
			if (isset($_POST['unassign'])) {
				// Unassign from tasks
				foreach ($_POST['task'] as $id => $sel) {
					SQL_QUERY_ESC("UPDATE `{!_MYSQL_PREFIX!}_task_system` SET assigned_admin=0 WHERE id=%s AND assigned_admin=%s LIMIT 1",
						array(bigintval($id), GET_CURRENT_ADMIN_ID()), __FILE__, __LINE__);
				}
			} elseif (isset($_POST['del'])) {
				// Delete tasks
				foreach ($_POST['task'] as $id => $sel) {
					if ($_GET['type'] == "deleted") {
						// Delete task immediately
						SQL_QUERY_ESC("DELETE LOW_PRIORITY FROM `{!_MYSQL_PREFIX!}_task_system` WHERE id=%s LIMIT 1",
							array(bigintval($id)),__FILE__, __LINE__);
					} else {
						// Mark task as to be deleted (purged by autppurge extension)
						ADMIN_DELETE_TASK($id);
					}
				}
			}

			// Update query
			$result_tasks = SQL_QUERY("SELECT id, assigned_admin, userid, task_type, subject, text, task_created FROM `{!_MYSQL_PREFIX!}_task_system` WHERE ".$whereStatement." ORDER BY subject, task_created DESC", __FILE__, __LINE__);
		}

		// There are uncompleted jobs!
		$type = constant('ADMIN_OVERVIEW_TASK_'.strtoupper($_GET['type']).'_TYPE');
		LOAD_TEMPLATE("admin_overview_header_task", false, array(
			'message' => $type,
			'type'    => $_GET['type']
		));
		$SW = 2;
		while (list($id, $admin, $uid, $type, $subj, $text, $created) = SQL_FETCHROW($result_tasks)) {
			// Init infos
			$infos = "---";

			// Generate link
			$admin = GENERATE_AID_LINK($admin);

			// Get admin task
			$type_out = constant('ADMIN_TASK_IS_'.strtoupper($type).'');

			$type2 = substr($text, 0, strpos($text, ":"));
			// Generate infos
			switch ($type)
			{
			case "EXTENSION":
			case "EXTENSION_UPDATE":
				$infos = substr($subj, 1, strpos($subj, ":") - 1);
				break;
			}

			// Member assigned with task?
			if ($uid > 0) {
				// Member found otherwise it's a system task
				$uid = ADMIN_USER_PROFILE_LINK($uid);
			} else {
				// Is a system task!
				$uid = "<em>".ADMIN_IS_SYSTEM_TASK."</em>";
			}

			// Prepare content
			$content = array(
				'sw'      => $SW,
				'id'      => $id,
				'admin'   => $admin,
				'infos'   => $infos,
				'uid'     => $uid,
				'type'    => $type_out,
				'created' => MAKE_DATETIME($created, "2")
			);

			// Do we have an extension task?
			if (($type == "EXTENSION") && (GET_EXT_VERSION($infos) == "")) {
				// Load extension row template
				LOAD_TEMPLATE("admin_list_task_ext_rows", false, $content);
			} else {
				// Load default row template
				LOAD_TEMPLATE("admin_list_task_rows", false, $content);
			}

			// Switch colors
			$SW = 3 - $SW;
		}

		// Free memory
		SQL_FREERESULT($result_tasks);

		// Load footer template
		if ($_GET['type'] == "deleted")
		{
			// Delete now button
			LOAD_TEMPLATE("admin_overview_footer_task");
		}
		 else
		{
			// Normal footer
			LOAD_TEMPLATE("admin_overview_footer");
		}
	}
}
//
?>
